/* 
   - The contents of this file are subject to the Mozilla Public
   - License Version 1.1 (the "License"); you may not use this file
   - except in compliance with the License. You may obtain a copy of
   - the License at http://www.mozilla.org/MPL/
   -
   - Software distributed under the License is distributed on an "AS
   - IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
   - implied. See the License for the specific language governing
   - rights and limitations under the License.
   -
   - The Original Code is this file as it was released on
   - March 20, 2000.
   -
   - The Initial Developer of the Original Code is HJ van Rantwijk.
   - Portions created by HJ van Rantwijk are Copyright (C) 2000-2007
   - HJ van Rantwijk.  All Rights Reserved.
   - 
   - Contributors:
   -	Michael Vincent van Rantwijk <mv_van_rantwijk@yahoo.com>
   - 
*/


function initTabContextMenu()
{
  var popupNode = document.popupNode;

  if (popupNode && popupNode.localName == 'toolbarbutton')
    popupNode = getBrowser().selectedTab;
  initGoogleBoxMenuitem("GoogleBoxToolbarsMenuitem");

  if (popupNode.hasAttribute("customLabel")) {
    document.getElementById("setStickyMenuItem").setAttribute("hidden", "true");
    document.getElementById("clearStickyMenuItem").removeAttribute("hidden");
  }
  else {
    document.getElementById("clearStickyMenuItem").setAttribute("hidden", "true");
    document.getElementById("setStickyMenuItem").removeAttribute("hidden");
  }
  initToolbarsMenu();
}

function initToolbarsMenu()
{
  // Update Menu/View/Show-Hide to reflect the current state of the Tab Bar
  // We need this because we now use observes in our Toolbars menu
  var tabbarMenuItem = document.getElementById("menuitem_showhide_tabbar");
  var tabBarDisplayed = gBrowser.getStripVisibility();
  tabbarMenuItem.setAttribute("checked", tabBarDisplayed);
  // Overwrite the disabled state in updateToolbarStates() in navigator.js
  // This allows the user to hide/show the Tab Bar, at any time
  tabbarMenuItem.removeAttribute("disabled");
}

function initTabImportMenu(importMenu)
{
  var navigatorWindows = 0;
  var item = importMenu.childNodes[1];
  var windowManagerDS = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService(nsIWindowDataSource);

  while ((item = item.nextSibling)) {
    var windowID = item.getAttribute('id');
    var win = windowManagerDS.getWindowForResource(windowID);

    if (win && win == window) {
      item.setAttribute("checked", "true");
      item.setAttribute("disabled", "true");
    }
    else {
      if (isNavigatorWindow(win))
        navigatorWindows++;
      else
        item.setAttribute("disabled", "true");
    }
  }
  importMenu.firstChild.setAttribute("disabled", (navigatorWindows < 2) ? "true" : "false");
}

function importTabsByWindowId(aWindowId)
{
  var windowManagerDS = Components.classes['@mozilla.org/rdf/datasource;1?name=window-mediator'].getService(nsIWindowDataSource);
  var sourceWindow = windowManagerDS.getWindowForResource(aWindowId);
  var targetWindow = window;

  if (!sourceWindow || sourceWindow == targetWindow || !isNavigatorWindow(sourceWindow)) 
    return;

  var sourceTabbrowser = sourceWindow.getBrowser();
  var targetTabbrowser = targetWindow.getBrowser();
  var numberOfTabs = sourceTabbrowser.mTabContainer.childNodes.length;

  for (var i = 0; i < numberOfTabs; i++) {
    var url = sourceTabbrowser.browsers[i].currentURI.spec;

    if (url && url != "about:blank") {
      var blankBrowser = checkForBlankTab(targetTabbrowser); // Try to locate a new/unused blank tab

      if (blankBrowser)
        blankBrowser.loadURI(url);
      else 
        targetTabbrowser.addTab(url);
    }
  }
}

function importAllTabs(aMenuitem)
{
  while ((aMenuitem = aMenuitem.nextSibling)) {
    importTabsByWindowId(aMenuitem.getAttribute('id'));
  }
}

function initTabExportMenu(aParent) 
{
  // var panelContainer = gBrowser.mPanelContainer;
  var numberOfTabs = gBrowser.mTabContainer.childNodes.length;

  deleteHistoryItems(aParent); // this depends on sessionHistoryUI.js

  for (var i = 0; i < numberOfTabs; i++) {
    var tab = gBrowser.mTabs[i];
    // var tabURL = panelContainer.childNodes[tab.ordinal].currentURI.spec; // this might fail for busy tabs!
    var url = tab.linkedBrowser.currentURI.spec; // this might fail for busy tabs!
    var menuitem = document.createElement("menuitem");
    menuitem.setAttribute("label", tab.label);
    menuitem.setAttribute("url", url);
    // set index based on tab.ordinal, to make deleteHistoryItems() work,
	// and we also use this attribute, as ordinal, in function exportTab!
    menuitem.setAttribute("index", i); // tab.ordinal);
    // The following code is copied from method initRestoreTabMenu in tabbrowser.xml
    menuitem.setAttribute("class", "menuitem-iconic bookmark-item"); // Display default bookmarks icon
    var iconURL = tab.getAttribute("image");

    if (iconURL && iconURL.match(/^http/i)) {
      if (isImageCached(iconURL)) { 
        menuitem.setAttribute("class", "menuitem-iconic");
        menuitem.setAttribute("src", iconURL);
      }
    }
    aParent.appendChild(menuitem);

    if (url == "about:blank")
      menuitem.setAttribute("disabled", "true");
  }
  aParent.firstChild.setAttribute("disabled", (aParent.childNodes.length == 3) ? "true" : "false");
}

function exportTabs(aMenuitem)
{
  // do we have to export all tabs to new windows?
  if (aMenuitem.id == "ExportAllTabs") {
    aMenuitem = aMenuitem.nextSibling;

    while ((aMenuitem = aMenuitem.nextSibling)) {
      exportTab(aMenuitem);
    }
  }
  else { // no, just export the selected tab to a new window
    exportTab(aMenuitem);
  }
}

function exportTab(aMenuitem)
{
  // we skip the disabled 'about:blank' tabs
  if (!aMenuitem.hasAttribute("disabled")) {
    var windowID = openWindowAndReturnWindowID();
    // get ordinal from attribute index because that's what it is ;)
    var index = Number(aMenuitem.getAttribute("index"));
    var tab = gBrowser.mTabs[index];
    // call function moveTabToWindow, because that also handles history
    moveTabToWindow(tab, windowID, false);
  }
}

